@@ -72,7 +72,8 @@ class DataMediator:
                 self.filter(value)
             if flag == "verbose":
                 self.verbose = value
-        self.__balance(self.balancingMethodCallback)
+        if balancingMethod:
+            self.__balance(self.balancingMethodCallback)
 
     @staticmethod
     def transposeDataFrame(
