@@ -118,6 +118,9 @@ class NeptuneExperimentTracker(ExperimentTracker):
         loggable = self.project if projectLevel else self.tracker
 
         for (key, value) in valueMap.items():
+            if key in loggable:
+                del loggable[key]
+
             if isinstance(value, Figure):
                 fileHandle, previewHandle = BytesIO(), BytesIO()
                 value.savefig(fileHandle, format="svg", bbox_inches="tight")
